/*
 * tclMacInit.c --
 *
 *	Contains the Mac-specific interpreter initialization functions.
 *
 * Copyright (c) 1995 Sun Microsystems, Inc.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

static char sccsid[] = "@(#) tclMacInit.c 1.6 95/09/11 10:32:43";

#include <Files.h>
#include <TextUtils.h>
#include <Strings.h>
#include "tclInt.h"
#include "tclPort.h"

/*
 *----------------------------------------------------------------------
 *
 * TclPlatformInit --
 *
 *	Performs Unix-specific interpreter initialization related to the
 *      tcl_library variable.
 *
 * Results:
 *	None.
 *
 * Side effects:
 *	Sets "tcl_library" Tcl variable
 *
 *----------------------------------------------------------------------
 */

void
TclPlatformInit(interp)
    Tcl_Interp *interp;
{
    char *libDir, *tempPath;
    Tcl_DString path;
    FSSpec macDir;

    Tcl_DStringInit(&path);

    /*
     * The tcl_library path can be found in several places.  Here is the order
     * in which the are searched.
     *		1) env array
     *		2) System Folder:Extensions:Tool Command Language:
     *		3) use TCL_LIBRARY - which probably won't work
     */
     
    libDir = Tcl_GetVar2(interp, "env", "TCL_LIBRARY", TCL_GLOBAL_ONLY);
    if (libDir == NULL) {
	tempPath = Tcl_GetVar2(interp, "env", "EXT_FOLDER", TCL_GLOBAL_ONLY);
	if (tempPath == NULL) {
	    Tcl_DStringAppend(&path, tempPath, -1);
	    Tcl_DStringAppend(&path, ":Tool Command Language:lib:", -1);
	    Tcl_DStringAppend(&path, TCL_VERSION, -1);
	    c2pstr(path.string);
	    if (FSMakeFSSpec(0, 0, (StringPtr) path.string, &macDir) == noErr) {
		p2cstr((StringPtr) path.string);
	    	libDir = path.string;
	    }
	}
    }
    if (libDir == NULL) {
	libDir = TCL_LIBRARY;
    }
    Tcl_SetVar(interp, "tcl_library", libDir, TCL_GLOBAL_ONLY);
    Tcl_DStringFree(&path);
}

/*
 *----------------------------------------------------------------------
 *
 * Tcl_Init --
 *
 *	This procedure is typically invoked by Tcl_AppInit procedures
 *	to perform additional initialization for a Tcl interpreter,
 *	such as sourcing the "init.tcl" script.
 *
 * Results:
 *	Returns a standard Tcl completion code and sets interp->result
 *	if there is an error.
 *
 * Side effects:
 *	Depends on what's in the init.tcl script.
 *
 *----------------------------------------------------------------------
 */

int
Tcl_Init(interp)
    Tcl_Interp *interp;		/* Interpreter to initialize. */
{
    /*
     * We will also add two Macintosh specific commands here.
     */
    Tcl_CreateCommand(interp, "beep", Mac_BeepCmd, NULL, NULL);
    Tcl_CreateCommand(interp, "source", Mac_SourceCmd, NULL, NULL);

    /*
     * For Macintosh applications we supply the init.tcl as a TEXT
     * resource.  Rather than use the standard Unix approach of testing for
     * it's existance in an environment variable or a set location, we just
     * source it from the resource fork.
     */
    
    if (Tcl_Eval(interp, "source -rsrc {Init}") == TCL_ERROR) {
	Tcl_AppendResult(interp, "can't find Init resource", (char *) NULL);
	return TCL_ERROR;
    }

    return TCL_OK;
}
